//---------------------------------------------------------------------
//  Copyright (C) Microsoft Corporation.  All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
//---------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Windows.Forms.Design.Behavior;

namespace DesignSurfaceExtenderLibrary.Extensions
{
    internal class AnchorBehavior : Behavior
    {   
        public override bool OnMouseDoubleClick(
            Glyph g,
            MouseButtons button,
            Point mouseLoc )
        {
            base.OnMouseDoubleClick( g, button, mouseLoc );

            if( button == MouseButtons.Left )
            {
                AnchorGlyph ag = g as AnchorGlyph;
                PropertyDescriptor pdAnchor =
                    TypeDescriptor.GetProperties( ag.RelatedControl )["Anchor"];

                if( ag.IsEnabled )
                {
                    // The glyph is enabled. 
                    // Clear the AnchorStyle flag to disable the Glyph.
                    pdAnchor.SetValue(
                        ag.RelatedControl,
                        ag.RelatedControl.Anchor ^ ag.AnchorStyle );
                }
                else
                {
                    // The glyph is disabled. 
                    // Set the AnchorStyle flag to enable the Glyph.
                    pdAnchor.SetValue(
                        ag.RelatedControl,
                        ag.RelatedControl.Anchor | ag.AnchorStyle );
                }

            }

            return true;
        }
    }
}
