//---------------------------------------------------------------------
//  Copyright (C) Microsoft Corporation.  All rights reserved.
// 
// THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
// KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
// PARTICULAR PURPOSE.
//
//---------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace DesignSurfaceExtenderLibrary.Extensions
{
    internal class PaddingBehavior : BoundsBehavior
    {
        internal PaddingBehavior( IServiceProvider serviceProvider )
            : base( serviceProvider )
        {
            this.propertyName = "Padding";
            this.transactionName = "Padding drag";
        }

        protected override void SetBoundsProperty( PropertyDescriptor pd )
        {
            if( pd != null )
            {
                Rectangle translatedBounds = new Rectangle(
                    this.behaviorServiceValue.ControlToAdornerWindow( this.relatedControl ),
                    this.relatedControl.Size );

                switch( this.selectedEdge )
                {
                    case EdgeSelection.Left:
                    {
                        int leftPadding = this.currentPosition.X - translatedBounds.Left;

                        if( leftPadding >= 0 )
                        {
                            Padding padding = new Padding(
                                leftPadding,
                                this.relatedControl.Padding.Top,
                                this.relatedControl.Padding.Right,
                                this.relatedControl.Padding.Bottom );

                            pd.SetValue( this.relatedControl, padding );
                        }

                        break;
                    }

                    case EdgeSelection.Top:
                    {
                        int bottomPadding = this.currentPosition.Y - translatedBounds.Top;

                        if( bottomPadding >= 0 )
                        {
                            Padding padding = new Padding(
                                this.relatedControl.Padding.Left,
                                bottomPadding,
                                this.relatedControl.Padding.Right,
                                this.relatedControl.Padding.Bottom );

                            pd.SetValue( this.relatedControl, padding );
                        }

                        break;
                    }

                    case EdgeSelection.Right:
                    {
                        int rightPadding = translatedBounds.Right - this.currentPosition.X;

                        if( rightPadding >= 0 )
                        {
                            Padding padding = new Padding(
                                this.relatedControl.Padding.Left,
                                this.relatedControl.Padding.Top,
                                rightPadding,
                                this.relatedControl.Padding.Bottom );

                            pd.SetValue( this.relatedControl, padding );
                        }

                        break;
                    }

                    case EdgeSelection.Bottom:
                    {
                        int bottomPadding = translatedBounds.Bottom - this.currentPosition.Y;

                        if( bottomPadding >= 0 )
                        {
                            Padding padding = new Padding(
                                this.relatedControl.Padding.Left,
                                this.relatedControl.Padding.Top,
                                this.relatedControl.Padding.Right,
                                bottomPadding );

                            pd.SetValue( this.relatedControl, padding );
                        }

                        break;
                    }

                    case EdgeSelection.None:
                    default:
                    {
                        break;
                    }
                }
            }
        }
    }
}
